@@ -82,7 +82,7 @@ Evo::Class
 
 =head1 VERSION
 
-version 0.0247
+version 0.0248
 
 =head1 DESCRIPTION
 
@@ -355,6 +355,39 @@ You may want to use C<extends> and C<implements> separately to resolve circular
 
 Mark name as overridden. Overridden means it will override the "parent's" method with the same name without diying
 
+=head2 WORKING WITH NON-EVO PARENT CLASSES
+
+In some case you may wish to inherite from non-evo classes using C<@ISA>. Evo class won't prevent that, but it will check method clashing and you wouldn't be able to pass that inheritance to children because Evo don't use C<@ISA> (but you can reinherit alien classes directly in the child)
+
+You can also reimplement clashing methods with C<:Over> attribute, if both of Evo parent and @ISA parent have the same method.
+
+  use Evo;
+
+  {
+
+    package My::Evo::Parent;
+    use Evo -Loaded, -Class;
+    sub foo {'EVO'}
+
+    package My::Isa::Parent;
+    use Evo -Loaded, -Class;
+    sub foo {'ISA'}
+
+    package My::Child;
+    use Evo -Class;
+    use parent 'My::Isa::Parent';
+    with 'My::Evo::Parent';
+
+    # without this, an error will be thrown because Evo doesn't know
+    # wich foo do you need here
+    sub foo : Over { My::Evo::Parent::foo(@_) }
+
+  }
+
+  say My::Child->foo();    # EVO
+
+This is actually a good thing, because it prevents you from most of the "multiple inheritance" errors.
+
 =head1 AUTHOR
 
 alexbyk.com
