@@ -83,6 +83,10 @@ sub reg_attr ($self, $name, @opts) {
   _check_exists_valid_name($self, $name);
   my $pkg = $self->package;
   croak qq{$pkg already has subroutine "$name"} if Evo::Internal::Util::names2code($pkg, $name);
+
+  croak
+    qq/$pkg already has a (probably inherited by \@ISA) method "$name", define implementation with "has_over" or :Over/
+    if $pkg->can($name);
   my $sub = $self->attrs->gen_attr($name, @opts);    # register
   Evo::Internal::Util::monkey_patch $pkg, $name, $sub;
 }
@@ -147,6 +151,9 @@ sub extend_with ($self, $source_p) {
     next if $self->is_overridden($name);
     croak qq/$dest_p already has a subroutine with name "$name"/
       if Evo::Internal::Util::names2code($dest_p, $name);
+    croak
+      qq/$dest_p already has a (probably inherited by \@ISA) method "$name", define implementation with :Over tag/
+      if $dest_p->can($name);
     _check_exists($self, $name);    # prevent patching before check
     Evo::Internal::Util::monkey_patch $dest_p, $name, $methods{$name};
     $self->reg_method($name);
@@ -255,7 +262,7 @@ Evo::Class::Meta
 
 =head1 VERSION
 
-version 0.0247
+version 0.0248
 
 =head1 METHODS
 
